aboutsummaryrefslogtreecommitdiffstats
path: root/lib/AdminPanel/Category.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/AdminPanel/Category.pm')
-rw-r--r--lib/AdminPanel/Category.pm12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/AdminPanel/Category.pm b/lib/AdminPanel/Category.pm
index 5448f1a..4ef7fa7 100644
--- a/lib/AdminPanel/Category.pm
+++ b/lib/AdminPanel/Category.pm
@@ -1,24 +1,24 @@
# vim: set et ts=4 sw=4:
# Copyright 2012 Steven Tucker
#
-# This file is part of AdminPanel
+# This file is part of ManaTools
#
# AdminPanel is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# AdminPanel is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with AdminPanel. If not, see <http://www.gnu.org/licenses/>.
+# along with ManaTools. If not, see <http://www.gnu.org/licenses/>.
#Class Category
-package AdminPanel::Category;
+package ManaTools::Category;
use strict;
use warnings;
@@ -56,7 +56,7 @@ sub new {
icon => 0,
modules => [],
};
- bless $self, 'AdminPanel::Category';
+ bless $self, 'ManaTools::Category';
$self->{name} = $newName;
$self->{icon} = $newIcon;
@@ -1,24 +1,24 @@
#
-# AdminPanel is free software: you can redistribute it and/or modify
+# ManaTools is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
@@ -1,24 +1,24 @@
# (at your option) any later version.
#
-# AdminPanel is distributed in the hope that it will be useful,
+# ManaTools is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the